@@ -8,7 +8,7 @@
 (custom-add-loads 'extensions '("iswitchb" "page-ext" "tempo"))
 (custom-add-loads 'recent-files-menu '("recent-files"))
 (custom-add-loads 'mouse '("avoid" "id-select" "outl-mouse"))
-(custom-add-loads 'convenience '("power-macros"))
+(custom-add-loads 'convenience '("dabbrev" "power-macros"))
 (custom-add-loads 'menu '("recent-files"))
 (custom-add-loads 'minibuffer '("detached-minibuf" "icomplete" "savehist"))
 (custom-add-loads 'environment '("popper"))
@@ -47,7 +47,6 @@
 (custom-add-loads 'font-lock '("lazy-lock"))
 (custom-add-loads 'where-was-i '("where-was-i-db"))
 (custom-add-loads 'popper '("popper"))
-(custom-add-loads 'manual '("man"))
 (custom-add-loads 'tempo '("tempo"))
 (custom-add-loads 'detached-minibuf '("detached-minibuf"))
 (custom-add-loads 'resize-minibuffer '("rsz-minibuf"))
