@@ -925,7 +925,7 @@ displayed in the modeline.")
 ;;; David Hughes <d.hughes@videonetworks.com>
 ;;; Paul Filipski & Anthony Girardin <{filipski,girardin}@blackhawk.com>
 (defvar fume-function-name-regexp-make
-  "^\\(\\(\\$\\s(\\)?\\(\\w\\|\\.\\|\\_\\|\\/\\)+\\(:sh\\)?\\(\\s)\\)?\\)\\s *\\(::?\\|\\+?=\\)"
+  "^\\(\\(\\$\\s(\\)?\\(\\w\\|\\s_\\|\\.\\)+\\(:sh\\)?\\(\\s)\\)?\\)\\s *\\(::?\\|\\+?=\\)"
   "Expression to get makefile target names
 
 Add the following line to your .emacs if you want Makefile support. Note, this
@@ -1673,9 +1673,24 @@ Otherwise returns fume-function-name-regexp"
 
 ;;; Routines to add/remove/update function menu from menubar
 ;;;
-(defun fume-add-menubar-entry ()
+(defun fume-add-menubar-entry (&optional force)
+  "Add a menubar entry for the functions in the current buffer.
+Meant to be added to `find-file-hooks'.  If FORCE is non-nil, actually
+do the operation now; otherwise, delay until the next time the event
+loop is processed. (This is so that Lisp routines that temporarily load
+a file, process it, and then kill it will not be slowed down by
+function-menu processing.)"
   (interactive)
-  (save-window-excursion (function-menu t)))
+  (if force
+      (save-window-excursion (function-menu t))
+    (enqueue-eval-event 'fume-do-add-menubar-entry (current-buffer))))
+
+(defun fume-do-add-menubar-entry (buffer)
+  (and (buffer-live-p buffer)
+       (save-excursion
+	 (save-window-excursion
+	   (set-buffer buffer)
+	   (function-menu t)))))
 
 (defun fume-remove-menubar-entry ()
   (interactive)
@@ -1689,7 +1704,7 @@ Otherwise returns fume-function-name-regexp"
   (and fume-running-xemacs
        fume-not-tty
        (assoc fume-menubar-menu-name current-menubar)
-       (fume-add-menubar-entry)
+       (fume-add-menubar-entry t)
        t))
 
 (defun fume-replace-str (s r b e) (concat (substring s 0 b) r (substring s e)))
