@@ -1,4 +1,4 @@
-;;; mic-paren.el --- advanced highlighting of matching parenthesises.
+;;; mic-paren.el --- advanced highlighting of matching parentheses.
 
 ;; Version: 3.3 - 2000-08-04
 ;; Author: Mikael Sjdin (mic@docs.uu.se)
@@ -83,12 +83,12 @@
 ;; when loaded) Emacs normal parenthesis matching is deactivated. Instead
 ;; parenthesis matching will be performed as soon as the cursor is
 ;; positioned at a parenthesis. The matching parenthesis (or the entire
-;; expression between the parenthesises) is highlighted until the cursor
+;; expression between the parentheses) is highlighted until the cursor
 ;; is moved away from the parenthesis. Features include:
 ;; o Both forward and backward parenthesis matching (simultaneously if
 ;;   cursor is between two expressions).
-;; o Indication of mismatched parenthesises.
-;; o Recognition of "escaped" (also often called "quoted") parenthesises.
+;; o Indication of mismatched parentheses.
+;; o Recognition of "escaped" (also often called "quoted") parentheses.
 ;; o Option to match "escaped" parens too, especially in (La)TeX-mode
 ;;   (e.g. matches expressions like "\(foo bar\)" properly).
 ;; o Offers two functions as replacement for forward-sexp and
@@ -109,7 +109,7 @@
 ;; o Numerous options to control the behaviour and appearance of
 ;;   mic-paren.el.
 ;;
-;; mic-paren.el was originaly developed and tested under Emacs 19.28 -
+;; mic-paren.el was originally developed and tested under Emacs 19.28 -
 ;; 20.3. It should work on earlier and forthcoming Emacs versions. XEmacs
 ;; compatibility has been provided by Steven L Baur <steve@xemacs.org>.
 ;; Jan Dubois (jaduboi@ibm.net) provided help to get mic-paren to work in
@@ -177,7 +177,7 @@
 ;;           the matching open paren is offscreen. In functional
 ;;           programming languages like lisp it is useful to display the
 ;;           following line in the echo-area if the opening matching paren
-;;           has no preceeding text in the same line.
+;;           has no preceding text in the same line.
 ;;           But in procedural languages like C++ or Java it is convenient
 ;;           to display the first previous non empty line in this case
 ;;           instead of the following line. Look at the new variable
@@ -260,7 +260,7 @@
 ;;	    <vinicius@cpqd.br> and Steven L Baur <steve@xemacs.org>)
 ;;
 ;; v1.3    Added code from Vinicius Jose Latorre <vinicius@cpqd.br> to
-;;	    highlight unmatched parenthesises (useful in minibuffer)
+;;	    highlight unmatched parentheses (useful in minibuffer)
 ;;
 ;; v1.2.1  Fixed stuff to work with OS/2 emx-emacs
 ;;           - checks if x-display-colour-p is bound before calling it
@@ -273,7 +273,7 @@
 ;; + mic-paren-horizontal-pos-visible-p seems to have a very little bug
 ;;   (in 99.99% it should work, but maybe the limit-values in the
 ;;   comparisons differ from the correct value by 1 or 2; normally this
-;;   doesnt matter!)
+;;   doesn't matter!)
 
 ;; Suggestions for further releases:
 ;;
@@ -328,7 +328,7 @@ situation like this: \(a b)\(c d)
 (defcustom paren-overlay-priority 999
  "*Specify paren overlay priority \(Integer >= 0\). For a description of the
 priority of an overlay see in the emacs-lisp manual the node Overlays.
-Normaly you dont want to change the default-value!"
+Normally you don't want to change the default-value!"
  :set #'(lambda (symbol value)
           (set symbol (if (< value 0) (* -1 value) value)))
  :initialize 'custom-initialize-default
@@ -343,7 +343,7 @@ highlighted instead of only the matching/mismatching parenthesis.
 - t: Always highlight the whole s-expression.
 - nil: Never highlight the whole s-expression.
 - 'match: Highlight the whole s-expression only if the parens match.
-- 'mismatch: Highlight the whole s-expression only if the parens dont match."
+- 'mismatch: Highlight the whole s-expression only if the parens don't match."
   :type '(choice (const :tag "Never sexp-mode" nil)
                  (const :tag "Always sexp-mode" t)
                  (const :tag "If match" match)
@@ -546,8 +546,8 @@ This package offers also two slightly modified versions of forward-sexp
 jump to escaped/quoted parens.
 If this variable is not nil and `paren-bind-modified-sexp-functions' is set
 to non nil then `paren-toggle-matching-quoted-paren' will also toggle
-the orginal binding of `forward-sexp' \(resp. backward-sexp\) between the
-orginal functions and the modified equivalents.
+the original binding of `forward-sexp' \(resp. backward-sexp\) between the
+original functions and the modified equivalents.
 
 Do NOT set this variable directly but use
 `paren-toggle-matching-quoted-paren' to activate/deactivate/toggle this
@@ -606,7 +606,7 @@ mode hook, e.g.:
 
 (make-variable-buffer-local 'paren-open-paren-context-backward)
 
-(defconst mic-paren-orginal-keybinding-of-sexp-functions
+(defconst mic-paren-original-keybinding-of-sexp-functions
   (list (car (where-is-internal 'forward-sexp))
         (car (where-is-internal 'backward-sexp))))
 
@@ -675,7 +675,7 @@ The following options are available via the customize-feature:
   `paren-mismatch-face'
   `paren-no-match-face'
   `paren-bind-modified-sexp-functions'
-The following options are setable via toggling functions \(look at the
+The following options are settable via toggling functions \(look at the
 documentation of these options for the names of these functions\):
   `paren-match-quoted-paren'
   `paren-match-paired-delimiter'
@@ -777,10 +777,10 @@ mode-hooks to activate or deactivate quoted paren matching."
   ;; versions paren-forward-sexp (resp. paren-backward-sexp)
   ;; if not bind it back to the original forward-sexp (resp. backward-sexp).
   (let ((key-forward-sexp (car
-                           mic-paren-orginal-keybinding-of-sexp-functions))
+                           mic-paren-original-keybinding-of-sexp-functions))
         (key-backward-sexp (car
                             (cdr
-                             mic-paren-orginal-keybinding-of-sexp-functions))))
+                             mic-paren-original-keybinding-of-sexp-functions))))
     (if (and paren-bind-modified-sexp-functions
              key-backward-sexp
              key-forward-sexp)
@@ -934,7 +934,7 @@ cleaning-up."
                (not (mic-paren-is-following-char-quoted (- (point) 2)))))
       (let (open matched-paren charquote)
         ;; if we want to match quoted parens we must change the syntax of
-        ;; the escape or quote-char temporaly. This will be undone later.
+        ;; the escape or quote-char temporarily. This will be undone later.
         (setq charquote (mic-paren-uncharquote (- (point) 2)))
         ;; Find the position for the open-paren
         (save-excursion
@@ -948,10 +948,10 @@ cleaning-up."
                 (setq open (scan-sexps (point) -1))
               (error nil))))
 
-        ;; we must call matching-paren because scan-sexps dont care about
+        ;; we must call matching-paren because scan-sexps don't care about
         ;; the kind of paren (e.g. matches '( and '}). matching-paren only
-        ;; returns the character displaying the matching paren in buffers
-        ;; syntax-table (regardless of the buffers current contents!).
+        ;; returns the character displaying the matching paren in buffer's
+        ;; syntax-table (regardless of the buffer's current contents!).
         ;; Below we compare the results of scan-sexps and matching-paren
         ;; and if different we display a mismatch.
         (setq matched-paren (matching-paren (preceding-char)))
@@ -1072,7 +1072,7 @@ cleaning-up."
                (not (mic-paren-is-following-char-quoted (1- (point))))))
       (let (close matched-paren charquote)
         ;; if we want to match quoted parens we must change the syntax of
-        ;; the escape or quote-char temporaly. This will be undo later.
+        ;; the escape or quote-char temporarily. This will be undone later.
         (setq charquote (mic-paren-uncharquote (1- (point))))
         ;; Find the position for the close-paren
         (save-excursion
@@ -1180,7 +1180,7 @@ cleaning-up."
 ;;; --------------------------------------------------
 
 (defun mic-paren-sexp-mode-p (mismatch)
-  "Check if we must highlght the whole sexp and return t if we must"
+  "Check if we must highlight the whole sexp and return t if we must"
   (cond ((eq paren-sexp-mode nil) nil)
         ((eq paren-sexp-mode t) t)
         ((eq paren-sexp-mode 'match) (not mismatch))
